@@ -67,11 +67,11 @@ var (
 	ErrNotChose = errors.New("you did not specify a shell")
 )
 
-//nolint:forbidigo // we need to use fmt.Print
+//nolintlint:forbidigo // we need to use fmt.Print
 func completion() *cli.Command {
 	return &cli.Command{
 		Name:  "completion",
-		Usage: "Generate completion script",
+		Usage: "generate completion script",
 		Description: `
 			 echo "source <(helmwave completion bash)" >> ~/.bashrc
 			 echo "source <(helmwave completion zsh)" >> ~/.zshrc"
@@ -83,11 +83,11 @@ func completion() *cli.Command {
 
 			switch c.Args().First() {
 			case "bash":
-				fmt.Print(bash)
+				fmt.Print(bash) //nolint:forbidigo
 
 				return nil
 			case "zsh":
-				fmt.Print(zsh)
+				fmt.Print(zsh) //nolint:forbidigo
 
 				return nil
 			default:
