@@ -8,6 +8,7 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/helmwave/helmwave/pkg/template"
 	"github.com/helmwave/helmwave/tests"
 	"github.com/stretchr/testify/suite"
 	"github.com/urfave/cli/v2"
@@ -17,8 +18,18 @@ type DiffLiveTestSuite struct {
 	suite.Suite
 }
 
-func (ts *DiffLiveTestSuite) TestImplementsAction() {
-	ts.Require().Implements((*Action)(nil), &DiffLive{})
+//nolintlint:paralleltest // uses helm repository.yaml flock
+func TestDiffLiveTestSuite(t *testing.T) {
+	// t.Parallel()
+	suite.Run(t, new(DiffLiveTestSuite))
+}
+
+func (ts *DiffLiveTestSuite) TestCmd() {
+	s := &DiffLive{}
+	cmd := s.Cmd()
+
+	ts.Require().NotNil(cmd)
+	ts.Require().NotEmpty(cmd.Name)
 }
 
 func (ts *DiffLiveTestSuite) TestRun() {
@@ -26,7 +37,7 @@ func (ts *DiffLiveTestSuite) TestRun() {
 	y := &Yml{
 		tpl:       filepath.Join(tests.Root, "02_helmwave.yml"),
 		file:      filepath.Join(tests.Root, "02_helmwave.yml"),
-		templater: "sprig",
+		templater: template.TemplaterSprig,
 	}
 
 	s := &Build{
@@ -43,9 +54,3 @@ func (ts *DiffLiveTestSuite) TestRun() {
 	ts.Require().NoError(s.Run(context.Background()))
 	ts.Require().NoError(d.Run(context.Background()))
 }
-
-//nolint:paralleltest // uses helm repository.yaml flock
-func TestDiffLiveTestSuite(t *testing.T) {
-	// t.Parallel()
-	suite.Run(t, new(DiffLiveTestSuite))
-}
