@@ -9,6 +9,7 @@ import (
 	"testing"
 
 	"github.com/helmwave/helmwave/pkg/kubedog"
+	"github.com/helmwave/helmwave/pkg/template"
 	"github.com/helmwave/helmwave/tests"
 	"github.com/stretchr/testify/suite"
 	"github.com/urfave/cli/v2"
@@ -18,8 +19,18 @@ type DownTestSuite struct {
 	suite.Suite
 }
 
-func (ts *DownTestSuite) TestImplementsAction() {
-	ts.Require().Implements((*Action)(nil), &Down{})
+//nolintlint:paralleltest // uses helm repository.yaml flock
+func TestDownTestSuite(t *testing.T) {
+	// t.Parallel()
+	suite.Run(t, new(DownTestSuite))
+}
+
+func (ts *DownTestSuite) TestCmd() {
+	s := &Down{}
+	cmd := s.Cmd()
+
+	ts.Require().NotNil(cmd)
+	ts.Require().NotEmpty(cmd.Name)
 }
 
 func (ts *DownTestSuite) TestRun() {
@@ -27,7 +38,7 @@ func (ts *DownTestSuite) TestRun() {
 	y := &Yml{
 		tpl:       filepath.Join(tests.Root, "02_helmwave.yml"),
 		file:      filepath.Join(tests.Root, "02_helmwave.yml"),
-		templater: "sprig",
+		templater: template.TemplaterSprig,
 	}
 
 	s := &Build{
@@ -51,9 +62,3 @@ func (ts *DownTestSuite) TestRun() {
 	ts.Require().NoError(u.Run(context.Background()))
 	ts.Require().NoError(d.Run(context.Background()))
 }
-
-//nolint:paralleltest // uses helm repository.yaml flock
-func TestDownTestSuite(t *testing.T) {
-	// t.Parallel()
-	suite.Run(t, new(DownTestSuite))
-}
