@@ -9,6 +9,7 @@ import (
 	"testing"
 
 	"github.com/helmwave/helmwave/pkg/kubedog"
+	"github.com/helmwave/helmwave/pkg/template"
 	"github.com/helmwave/helmwave/tests"
 	"github.com/stretchr/testify/suite"
 	"github.com/urfave/cli/v2"
@@ -18,8 +19,18 @@ type UpTestSuite struct {
 	suite.Suite
 }
 
-func (ts *UpTestSuite) TestImplementsAction() {
-	ts.Require().Implements((*Action)(nil), &Up{})
+//nolintlint:paralleltest // can't parallel because of setenv
+func TestUpTestSuite(t *testing.T) {
+	// t.Parallel()
+	suite.Run(t, new(UpTestSuite))
+}
+
+func (ts *UpTestSuite) TestCmd() {
+	s := &Up{}
+	cmd := s.Cmd()
+
+	ts.Require().NotNil(cmd)
+	ts.Require().NotEmpty(cmd.Name)
 }
 
 func (ts *UpTestSuite) TestAutoBuild() {
@@ -27,7 +38,7 @@ func (ts *UpTestSuite) TestAutoBuild() {
 	y := &Yml{
 		tpl:       filepath.Join(tests.Root, "01_helmwave.yml.tpl"),
 		file:      filepath.Join(tmpDir, "02_helmwave.yml"),
-		templater: "sprig",
+		templater: template.TemplaterSprig,
 	}
 
 	u := &Up{
@@ -46,9 +57,3 @@ func (ts *UpTestSuite) TestAutoBuild() {
 
 	ts.Require().NoError(u.Run(context.Background()))
 }
-
-//nolint:paralleltest // cannot parallel because of setenv
-func TestUpTestSuite(t *testing.T) {
-	// t.Parallel()
-	suite.Run(t, new(UpTestSuite))
-}
