@@ -8,6 +8,7 @@ import (
 	"testing"
 
 	"github.com/helmwave/helmwave/pkg/plan"
+	"github.com/helmwave/helmwave/pkg/template"
 	"github.com/helmwave/helmwave/tests"
 	"github.com/stretchr/testify/suite"
 )
@@ -16,8 +17,18 @@ type YmlTestSuite struct {
 	suite.Suite
 }
 
-func (ts *YmlTestSuite) TestImplementsAction() {
-	ts.Require().Implements((*Action)(nil), &Yml{})
+//nolintlint:paralleltest // can't parallel because of setenv
+func TestYmlTestSuite(t *testing.T) {
+	// t.Parallel()
+	suite.Run(t, new(YmlTestSuite))
+}
+
+func (ts *YmlTestSuite) TestCmd() {
+	s := &Yml{}
+	cmd := s.Cmd()
+
+	ts.Require().NotNil(cmd)
+	ts.Require().NotEmpty(cmd.Name)
 }
 
 func (ts *YmlTestSuite) TestRenderEnv() {
@@ -25,7 +36,7 @@ func (ts *YmlTestSuite) TestRenderEnv() {
 	y := &Yml{
 		tpl:       filepath.Join(tests.Root, "01_helmwave.yml.tpl"),
 		file:      filepath.Join(tmpDir, "01_helmwave.yml"),
-		templater: "sprig",
+		templater: template.TemplaterSprig,
 	}
 
 	value := "test01"
@@ -34,16 +45,10 @@ func (ts *YmlTestSuite) TestRenderEnv() {
 
 	ts.Require().NoError(y.Run(context.Background()))
 
-	b, err := plan.NewBody(context.Background(), y.file)
+	b, err := plan.NewBody(context.Background(), y.file, true)
 	ts.Require().NoError(err)
 
 	ts.Require().Equal(value, b.Project)
 	ts.Require().Len(b.Releases, 1)
 	ts.Require().Equal(value, b.Releases[0].Namespace())
 }
-
-//nolint:paralleltest // cannot parallel because of setenv
-func TestYmlTestSuite(t *testing.T) {
-	// t.Parallel()
-	suite.Run(t, new(YmlTestSuite))
-}
