@@ -1,5 +1,7 @@
 package helper
 
+import "golang.org/x/exp/slices"
+
 // EqualChecker is an interface that allows to check interface for equality.
 type EqualChecker[T any] interface {
 	Equal(T) bool
@@ -7,11 +9,9 @@ type EqualChecker[T any] interface {
 
 // In returns whether `search` appears in `target` slice.
 func In[T any, C EqualChecker[T]](search C, target []T) bool {
-	for i := range target {
-		if search.Equal(target[i]) {
-			return true
-		}
-	}
+	i := slices.IndexFunc(target, func(t T) bool {
+		return search.Equal(t)
+	})
 
-	return false
+	return i != -1
 }
