@@ -1,26 +1,24 @@
 package log
 
 import (
-	"context"
 	"fmt"
 
 	"github.com/helmwave/helmwave/pkg/helper"
-	"github.com/helmwave/helmwave/pkg/kubedog"
 	formatter "github.com/helmwave/logrus-emoji-formatter"
 	"github.com/mgutz/ansi"
 	log "github.com/sirupsen/logrus"
 	"github.com/urfave/cli/v2"
-	"github.com/werf/logboek"
 	utilruntime "k8s.io/apimachinery/pkg/util/runtime"
 )
 
+var Default = &Settings{}
+
 // Settings stores configuration for logger.
 type Settings struct {
 	level      string
 	format     string
 	color      bool
 	timestamps bool
-	width      int
 }
 
 // Flags returns CLI flags for logger settings.
@@ -42,18 +40,11 @@ func (l *Settings) Flags() []cli.Flag {
 		},
 		&cli.BoolFlag{
 			Name:        "log-color",
-			Usage:       "Force color",
+			Usage:       "on/off color",
 			Value:       true,
 			EnvVars:     []string{"HELMWAVE_LOG_COLOR"},
 			Destination: &l.color,
 		},
-		&cli.IntFlag{
-			Name:        "kubedog-log-width",
-			Usage:       "Set kubedog max log line width",
-			Value:       140,
-			EnvVars:     []string{"HELMWAVE_KUBEDOG_LOG_WIDTH"},
-			Destination: &l.width,
-		},
 		&cli.BoolFlag{
 			Name:        "log-timestamps",
 			Usage:       "Add timestamps to log messages",
@@ -73,23 +64,10 @@ func (l *Settings) Run(c *cli.Context) error {
 func (l *Settings) Init() error {
 	// Skip various low-level k8s client errors
 	// There are a lot of context deadline errors being logged
-	//nolint:reassign
-	utilruntime.ErrorHandlers = []func(error){
+	utilruntime.ErrorHandlers = []func(error){ //nolint:reassign
 		logKubernetesClientError,
 	}
 
-	if err := kubedog.SilenceKlog(context.Background()); err != nil {
-		return err
-	}
-
-	if err := kubedog.SilenceKlogV2(context.Background()); err != nil {
-		return err
-	}
-
-	if l.width > 0 {
-		logboek.DefaultLogger().Streams().SetWidth(l.width)
-	}
-
 	l.setFormat()
 
 	return l.setLevel()
@@ -152,3 +130,7 @@ func (l *Settings) setFormat() {
 func logKubernetesClientError(err error) {
 	log.WithError(err).Trace("kubernetes client error")
 }
+
+func (l *Settings) Format() string {
+	return l.format
+}
