@@ -9,10 +9,11 @@ import (
 
 	"github.com/helmwave/helmwave/pkg/helper"
 	"github.com/helmwave/helmwave/pkg/parallel"
+	"github.com/helmwave/helmwave/pkg/release"
 )
 
 // Export allows save plan to file.
-func (p *Plan) Export(ctx context.Context) error {
+func (p *Plan) Export(ctx context.Context, skipUnchanged bool) error {
 	if err := os.RemoveAll(p.dir); err != nil {
 		return fmt.Errorf("failed to clean plan directory %s: %w", p.dir, err)
 	}
@@ -23,6 +24,11 @@ func (p *Plan) Export(ctx context.Context) error {
 		}
 	}(p.tmpDir)
 
+	if skipUnchanged {
+		p.removeUnchanged()
+		p.Logger().Info("removed unchanged releases from plan")
+	}
+
 	wg := parallel.NewWaitGroup()
 	wg.Add(4)
 
@@ -60,6 +66,18 @@ func (p *Plan) Export(ctx context.Context) error {
 	return helper.SaveInterface(ctx, p.fullPath, p.body)
 }
 
+func (p *Plan) removeUnchanged() {
+	filtered := p.body.Releases[:0]
+
+	for _, rel := range p.body.Releases {
+		if !helper.In[release.Config](rel, p.unchanged) {
+			filtered = append(filtered, rel)
+		}
+	}
+
+	p.body.Releases = filtered
+}
+
 func (p *Plan) exportCharts() error {
 	for i, rel := range p.body.Releases {
 		l := p.Logger().WithField("release", rel.Uniq())
@@ -96,7 +114,7 @@ func (p *Plan) exportCharts() error {
 		}
 
 		chart := entries[0]
-		p.body.Releases[i].SetChart(path.Join(dst, chart.Name()))
+		p.body.Releases[i].SetChartName(path.Join(dst, chart.Name()))
 	}
 
 	return nil
