@@ -8,6 +8,7 @@ import (
 	"os"
 	"path/filepath"
 
+	"github.com/helmwave/helmwave/pkg/hooks"
 	"github.com/helmwave/helmwave/pkg/registry"
 	"github.com/helmwave/helmwave/pkg/release"
 	"github.com/helmwave/helmwave/pkg/release/uniqname"
@@ -19,16 +20,16 @@ import (
 )
 
 const (
-	// Dir is default directory for generated files.
+	// Dir is the default directory for generated files.
 	Dir = ".helmwave/"
 
-	// File is default file name for planfile.
+	// File is the default file name for planfile.
 	File = "planfile"
 
-	// Body is default file name for main config.
+	// Body is a default file name for the main config.
 	Body = "helmwave.yml"
 
-	// Manifest is default directory under Dir for manifests.
+	// Manifest is the default directory under Dir for manifests.
 	Manifest = "manifest/"
 
 	// Values is default directory for values.
@@ -45,17 +46,15 @@ var (
 
 // Plan contains full helmwave state.
 type Plan struct {
-	body     *planBody
-	dir      string
-	fullPath string
-
-	tmpDir string
+	body      *planBody
+	dir       string
+	fullPath  string
+	tmpDir    string
+	graphMD   string
+	templater string
 
 	manifests map[uniqname.UniqName]string
-
-	graphMD string
-
-	templater string
+	unchanged release.Configs
 }
 
 // NewAndImport wrapper for New and Import in one.
@@ -94,13 +93,13 @@ func (p *Plan) Logger() *log.Entry {
 	})
 }
 
-//nolint:lll
 type planBody struct {
-	Project      string           `yaml:"project" json:"project" jsonschema:"title=project name,description=reserved for future,example=my-awesome-project"`
-	Version      string           `yaml:"version" json:"version" jsonschema:"title=version of helmwave,description=will check current version and project version,pattern=^[0-9]+\\.[0-9]+\\.[0-9]+$,example=0.23.0,example=0.22.1"`
-	Repositories repo.Configs     `yaml:"repositories" json:"repositories" jsonschema:"title=repositories list,description=helm repositories"`
-	Registries   registry.Configs `yaml:"registries" json:"registries" jsonschema:"title=registries list,description=helm OCI registries"`
-	Releases     release.Configs  `yaml:"releases" json:"releases" jsonschema:"title=helm releases,description=what you wanna deploy"`
+	Project      string           `yaml:"project" json:"project" jsonschema:"title=project name,description=reserved for future,example=my-awesome-project"`                                                                         //nolint:lll
+	Version      string           `yaml:"version" json:"version" jsonschema:"title=version of helmwave,description=will check current version and project version,pattern=^[0-9]+\\.[0-9]+\\.[0-9]+$,example=0.23.0,example=0.22.1"` //nolint:lll
+	Repositories repo.Configs     `yaml:"repositories" json:"repositories" jsonschema:"title=repositories list,description=helm repositories"`                                                                                       //nolint:lll
+	Registries   registry.Configs `yaml:"registries" json:"registries" jsonschema:"title=registries list,description=helm OCI registries"`                                                                                           //nolint:lll
+	Releases     release.Configs  `yaml:"releases" json:"releases" jsonschema:"title=helm releases,description=what you wanna deploy"`                                                                                               //nolint:lll
+	Lifecycle    hooks.Lifecycle  `yaml:"lifecycle" json:"lifecycle" jsonschema:"title=lifecycle,description=helmwave lifecycle hooks"`                                                                                              //nolint:lll
 }
 
 func GenSchema() *jsonschema.Schema {
@@ -116,7 +115,7 @@ func GenSchema() *jsonschema.Schema {
 }
 
 // NewBody parses plan from file.
-func NewBody(ctx context.Context, file string) (*planBody, error) {
+func NewBody(ctx context.Context, file string, validate bool) (*planBody, error) {
 	b := &planBody{
 		Version: version.Version,
 	}
@@ -132,14 +131,12 @@ func NewBody(ctx context.Context, file string) (*planBody, error) {
 		return b, fmt.Errorf("failed to unmarshal YAML plan %s: %w", file, err)
 	}
 
-	// Setup dev version
-	// if b.Version == "" {
-	// 	 b.Version = version.Version
-	// }
+	if validate {
+		err = b.Validate()
 
-	err = b.Validate()
-	if err != nil {
-		return nil, err
+		if err != nil {
+			return nil, err
+		}
 	}
 
 	return b, nil
