@@ -4,13 +4,13 @@ import (
 	"context"
 	"fmt"
 
-	"helm.sh/helm/v3/pkg/action"
-
 	"github.com/helmwave/helmwave/pkg/helper"
 	"github.com/helmwave/helmwave/pkg/log"
 	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	"github.com/invopop/jsonschema"
 	"gopkg.in/yaml.v3"
+	"helm.sh/helm/v3/pkg/action"
+	"helm.sh/helm/v3/pkg/chartutil"
 	"helm.sh/helm/v3/pkg/release"
 )
 
@@ -27,15 +27,16 @@ type Config interface {
 	DownloadChart(string) error
 	BuildValues(string, string) error
 	Uninstall(context.Context) (*release.UninstallReleaseResponse, error)
-	Get() (*release.Release, error)
+	Get(int) (*release.Release, error)
 	List() (*release.Release, error)
-	Rollback(int) error
+	Rollback(context.Context, int) error
 	Status() (*release.Release, error)
 	Name() string
 	Namespace() string
-	Chart() Chart
-	SetChart(string)
+	Chart() *Chart
+	SetChartName(string)
 	DependsOn() []*DependsOnReference
+	SetDependsOn([]*DependsOnReference)
 	Tags() []string
 	Repo() string
 	Values() []ValuesReference
@@ -43,6 +44,7 @@ type Config interface {
 	KubeContext() string
 	Cfg() *action.Configuration
 	HooksDisabled() bool
+	OfflineKubeVersion() *chartutil.KubeVersion
 }
 
 // Configs type of array Config.
