@@ -3,6 +3,7 @@
 package release_test
 
 import (
+	"context"
 	"testing"
 
 	"github.com/helmwave/helmwave/pkg/release"
@@ -18,7 +19,7 @@ func (s *RollbackTestSuite) TestNonExistingRollback() {
 	rel.NameF = "blabla"
 	rel.NamespaceF = "blabla"
 
-	err := rel.Rollback(1)
+	err := rel.Rollback(context.Background(), 1)
 
 	s.Require().ErrorContains(err, "failed to rollback release blabla@blabla:")
 }
