@@ -17,19 +17,17 @@ import (
 	"gopkg.in/yaml.v3"
 )
 
-// ErrSkipValues is returned when values cannot be used and are skipped.
-var ErrSkipValues = errors.New("values have been skipped")
+// ErrValuesNotExist is returned when values can't be used and are skipped.
+var ErrValuesNotExist = errors.New("values file doesn't exist")
 
 // ValuesReference is used to match source values file path and temporary.
-//
-//nolint:lll
 type ValuesReference struct {
 	Src            string `yaml:"src" json:"src" jsonschema:"required,description=Source of values. Can be local path or HTTP URL"`
-	Dst            string `yaml:"dst" json:"dst"`
-	DelimiterLeft  string `yaml:"delimiter_left,omitempty" json:"delimiter_left,omitempty" jsonschema:"Set left delimiter for template engine,default={{"`
-	DelimiterRight string `yaml:"delimiter_right,omitempty" json:"delimiter_right,omitempty" jsonschema:"Set right delimiter for template engine,default=}}"`
-	Strict         bool   `yaml:"strict" json:"strict" jsonschema:"description=Whether to fail if values is not found,default=false"`
-	Render         bool   `yaml:"render" json:"render" jsonschema:"description=Whether to use templater to render values,default=true"`
+	Dst            string `yaml:"dst" json:"dst" `
+	DelimiterLeft  string `yaml:"delimiter_left,omitempty" json:"delimiter_left,omitempty"  jsonschema:"Set left delimiter for template engine,default={{"`   //nolint:lll
+	DelimiterRight string `yaml:"delimiter_right,omitempty" json:"delimiter_right,omitempty" jsonschema:"Set right delimiter for template engine,default=}}"` //nolint:lll
+	Strict         bool   `yaml:"strict" json:"strict" jsonschema:"description=Whether to fail if values is not found,default=false"`                         //nolint:lll
+	Render         bool   `yaml:"render" json:"render"  jsonschema:"description=Whether to use templater to render values,default=true"`                      //nolint:lll
 }
 
 func (v ValuesReference) JSONSchema() *jsonschema.Schema {
@@ -79,7 +77,7 @@ func (v *ValuesReference) UnmarshalYAML(node *yaml.Node) error {
 }
 
 // MarshalYAML is used to implement Marshaler interface of gopkg.in/yaml.v3.
-func (v ValuesReference) MarshalYAML() (interface{}, error) {
+func (v ValuesReference) MarshalYAML() (any, error) {
 	return struct {
 		Src string
 		Dst string
@@ -138,10 +136,10 @@ func ProhibitDst(values []ValuesReference) error {
 // }
 
 // SetViaRelease downloads and templates values file.
-// Returns ErrSkipValues if values cannot be downloaded or doesn't exist in local FS.
+// Returns ErrValuesNotExist if values can't be downloaded or doesn't exist in local FS.
 func (v *ValuesReference) SetViaRelease(rel Config, dir, templater string) error {
 	if !v.Render {
-		templater = "copy"
+		templater = template.TemplaterNone
 	}
 
 	v.SetUniq(dir, rel.Uniq())
@@ -175,21 +173,19 @@ func (v *ValuesReference) SetViaRelease(rel Config, dir, templater string) error
 	return nil
 }
 
-//nolint:nestif // it is still pretty easy to understand
+//nolintlint:nestif // it is still pretty easy to understand
 func (v *ValuesReference) fetch(l *log.Entry) error {
 	if v.isURL() {
 		err := v.Download()
 		if err != nil {
 			l.WithError(err).Warnf("%q skipping: cant download", v.Src)
 
-			if v.Strict {
-				return ErrSkipValues
-			}
+			return ErrValuesNotExist
 		}
 	} else if !helper.IsExists(v.Src) {
 		l.Warn("skipping: local file not found")
 
-		return ErrSkipValues
+		return ErrValuesNotExist
 	}
 
 	return nil
@@ -197,13 +193,18 @@ func (v *ValuesReference) fetch(l *log.Entry) error {
 
 func (rel *config) BuildValues(dir, templater string) error {
 	for i := len(rel.Values()) - 1; i >= 0; i-- {
-		err := rel.Values()[i].SetViaRelease(rel, dir, templater)
-		if errors.Is(ErrSkipValues, err) {
+		v := rel.Values()[i]
+		err := v.SetViaRelease(rel, dir, templater)
+		switch {
+		case !v.Strict && errors.Is(ErrValuesNotExist, err):
+			rel.Logger().WithError(err).WithField("values", v).Warn("skipping values...")
 			rel.ValuesF = append(rel.ValuesF[:i], rel.ValuesF[i+1:]...)
-		} else if err != nil {
-			rel.Logger().WithError(err).WithField("values", rel.Values()[i]).Fatal("failed to build values")
+		case err != nil:
+			rel.Logger().WithError(err).WithField("values", v).Error("failed to build values")
 
 			return err
+		default:
+			rel.Values()[i] = v
 		}
 	}
 
