@@ -1,12 +1,16 @@
 package template
 
+const (
+	TemplaterNone = "copy"
+)
+
 type noTemplater struct{}
 
 func (t noTemplater) Name() string {
-	return "copy"
+	return TemplaterNone
 }
 
-func (t noTemplater) Render(src string, data interface{}) ([]byte, error) {
+func (t noTemplater) Render(src string, data any) ([]byte, error) {
 	return []byte(src), nil
 }
 
